==> u_team_core-fabric-1.20.1-5.1.4.382-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/entity/TestEnderPearl.java <==
package info.u_team.u_team_test.test_multiloader.entity;

import info.u_team.u_team_test.test_multiloader.init.TestMultiLoaderEntityTypes;
import info.u_team.u_team_test.test_multiloader.init.TestMultiLoaderItems;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2398;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3857;
import net.minecraft.class_3966;

public class TestEnderPearl extends class_3857 {
	
	public TestEnderPearl(class_1299<? extends TestEnderPearl> type, class_1937 world) {
		super(type, world);
	}
	
	public TestEnderPearl(class_1937 world, class_1309 thrower) {
		super(TestMultiLoaderEntityTypes.TEST_ENDERPEARL.get(), thrower, world);
	}
	
	@Override
	protected class_1792 method_16942() {
		return TestMultiLoaderItems.TEST_ENDERPEARL.get();
	}
	
	@Override
	protected float method_7490() {
		return 0.05F;
	}
	
	@Override
	protected void method_7454(class_3966 result) {
		super.method_7454(result);
		result.method_17782().method_5643(method_48923().method_48811(this, method_24921()), 0);
	}
	
	@Override
	protected void method_7488(class_239 result) {
		super.method_7488(result);
		
		for (int index = 0; index < 32; ++index) {
			method_37908().method_8406(class_2398.field_11214, this.method_23317(), this.method_23318() + field_5974.method_43058() * 2.0D, this.method_23321(), field_5974.method_43059(), 0.0D, field_5974.method_43059());
		}
		
		if (!method_37908().method_8608() && !method_31481()) {
			final class_1297 entity = method_24921();
			if (entity instanceof final class_3222 player) {
				if (player.field_13987.method_48106() && player.method_37908() == method_37908() && !player.method_6113()) {
					
					if (entity.method_5765()) {
						player.method_33567(method_23317(), method_23318(), method_23321());
					} else {
						entity.method_5859(method_23317(), method_23318(), method_23321());
					}
					
					entity.field_6017 = 0;
					entity.method_5643(method_48923().method_48827(), 2);
				}
			} else if (entity != null) {
				entity.method_5859(method_23317(), method_23318(), method_23321());
				entity.field_6017 = 0;
			}
			method_31472();
		}
		
	}
	
	@Override
	public void method_5773() {
		final class_1297 entity = method_24921();
		if (entity instanceof class_1657 && !entity.method_5805()) {
			method_31472();
		} else {
			super.method_5773();
		}
		
	}
	
	@Override
	public class_1297 method_5731(class_3218 level) {
		final class_1297 entity = method_24921();
		if (entity != null && entity.method_37908().method_27983() != level.method_27983()) {
			method_7432(null);
		}
		
		return super.method_5731(level);
	}
	
}

==> u_team_core-fabric-1.21.1-5.6.2.374-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/entity/TestEnderPearl.java <==
package info.u_team.u_team_test.test_multiloader.entity;

import info.u_team.u_team_test.test_multiloader.init.TestMultiLoaderEntityTypes;
import info.u_team.u_team_test.test_multiloader.init.TestMultiLoaderItems;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2398;
import net.minecraft.class_3222;
import net.minecraft.class_3857;
import net.minecraft.class_3966;

public class TestEnderPearl extends class_3857 {
	
	public TestEnderPearl(class_1299<? extends TestEnderPearl> type, class_1937 world) {
		super(type, world);
	}
	
	public TestEnderPearl(class_1937 world, class_1309 thrower) {
		super(TestMultiLoaderEntityTypes.TEST_ENDERPEARL.get(), thrower, world);
	}
	
	@Override
	protected class_1792 method_16942() {
		return TestMultiLoaderItems.TEST_ENDERPEARL.get();
	}
	
	@Override
	protected double method_7490() {
		return 0.05F;
	}
	
	@Override
	protected void method_7454(class_3966 result) {
		super.method_7454(result);
		result.method_17782().method_5643(method_48923().method_48811(this, method_24921()), 0);
	}
	
	@Override
	protected void method_7488(class_239 result) {
		super.method_7488(result);
		
		for (int index = 0; index < 32; ++index) {
			method_37908().method_8406(class_2398.field_11214, this.method_23317(), this.method_23318() + field_5974.method_43058() * 2.0D, this.method_23321(), field_5974.method_43059(), 0.0D, field_5974.method_43059());
		}
		
		if (!method_37908().method_8608() && !method_31481()) {
			final class_1297 entity = method_24921();
			if (entity instanceof final class_3222 player) {
				if (player.field_13987.method_48106() && player.method_37908() == method_37908() && !player.method_6113()) {
					
					if (entity.method_5765()) {
						player.method_33567(method_23317(), method_23318(), method_23321());
					} else {
						entity.method_5859(method_23317(), method_23318(), method_23321());
					}
					
					entity.field_6017 = 0;
					entity.method_5643(method_48923().method_48827(), 2);
				}
			} else if (entity != null) {
				entity.method_5859(method_23317(), method_23318(), method_23321());
				entity.field_6017 = 0;
			}
			method_31472();
		}
		
	}
	
	@Override
	public void method_5773() {
		final class_1297 entity = method_24921();
		if (entity instanceof class_1657 && !entity.method_5805()) {
			method_31472();
		} else {
			super.method_5773();
		}
		
	}
	
}
